pub struct ElementDescriptor {
pub name: &'static str,
pub aliases: &'static [&'static str],
pub source: ElementSource,
pub shape: ElementShape,
pub authority: ElementAuthority,
pub write_policy: ElementWritePolicy,
pub scheduling_role: ElementSchedulingRole,
pub realtime_model: ElementRealtimeModel,
pub composition_role: ElementCompositionRole,
pub realtime: bool,
}Expand description
Built-in descriptor shape. Plugin loaders can convert this to an owned descriptor later without changing element crate semantics.
Fields
name: &'static straliases: &'static [&'static str]source: ElementSourceshape: ElementShapewrite_policy: ElementWritePolicyscheduling_role: ElementSchedulingRolerealtime_model: ElementRealtimeModelcomposition_role: ElementCompositionRolerealtime: boolTrue when realtime processing may update this element outside turn closeout. Commits remain owned by the turn lifecycle.
Implementations
Sourceimpl ElementDescriptor
impl ElementDescriptor
pub fn matches_name(self, name: &str) -> bool
pub fn canonical_name(self, name: &str) -> Option<&'static str>
pub fn as_registration(self) -> ElementRegistration